@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.01';
+  $App::Pocoirc::VERSION = '0.02';
 }
 
 use strict;
@@ -436,8 +436,8 @@ to load locally (one object per component) or globally (single object)
      server: irc.perl.org
      nick:   hlagherf32fr
 
-The configuration file is in L<YAML|YAML> format. It consists of a hash
-containing C<global_plugins>, C<local_plugins>, C<networks>, C<lib>,
+The configuration file is in L<YAML|YAML> or L<JSON|JSON> format. It consists
+of a hash containing C<global_plugins>, C<local_plugins>, C<networks>, C<lib>,
 C<log_file>, and default parameters to POE::Component::IRC. Only C<networks>
 is required.
 
@@ -469,6 +469,63 @@ multiple IRC components simultaneously
 If you specify C<local_plugins> at the top level, it will serve as a default
 list of local plugins, which can be overridden in a network hash.
 
+=head1 OUTPUT
+
+Here is some example output from the program:
+
+ $ pocoirc -c example/config.yml
+ 2010-06-25 20:21:37 Started
+ 2010-06-25 20:21:37 Constructing global plugins
+ 2010-06-25 20:21:37 [freenode] Constructing local plugins
+ 2010-06-25 20:21:37 [freenode] Spawning IRC component
+ 2010-06-25 20:21:37 [magnet] Constructing local plugins
+ 2010-06-25 20:21:37 [magnet] Spawning IRC component
+ 2010-06-25 20:21:37 [freenode] Registering plugins
+ 2010-06-25 20:21:37 [freenode] Connecting to IRC
+ 2010-06-25 20:21:37 [magnet] Registering plugins
+ 2010-06-25 20:21:37 [magnet] Connecting to IRC
+ 2010-06-25 20:21:37 [freenode] Added plugin Whois3
+ 2010-06-25 20:21:37 [freenode] Added plugin ISupport3
+ 2010-06-25 20:21:37 [freenode] Added plugin DCC3
+ 2010-06-25 20:21:37 [magnet] Added plugin Whois6
+ 2010-06-25 20:21:37 [magnet] Added plugin ISupport6
+ 2010-06-25 20:21:37 [magnet] Added plugin DCC6
+ 2010-06-25 20:21:37 [freenode] Added plugin CTCP2
+ 2010-06-25 20:21:37 [freenode] Added plugin AutoJoin2
+ 2010-06-25 20:21:37 [magnet] Added plugin CTCP2
+ 2010-06-25 20:21:37 [magnet] Added plugin BotTraffic2
+ 2010-06-25 20:21:38 [freenode] Connected to server 213.92.8.4
+ 2010-06-25 20:21:38 [freenode] Server notice: *** Looking up your hostname...
+ 2010-06-25 20:21:38 [freenode] Server notice: *** Checking Ident
+ 2010-06-25 20:21:38 [freenode] Server notice: *** Found your hostname
+ 2010-06-25 20:21:38 [magnet] Connected to server 209.221.142.115
+ 2010-06-25 20:21:38 [magnet] Server notice: *** Looking up your hostname...
+ 2010-06-25 20:21:38 [magnet] Server notice: *** Checking Ident
+ 2010-06-25 20:21:39 [magnet] Server notice: *** Found your hostname
+ 2010-06-25 20:21:49 [freenode] Server notice: *** No Ident response
+ 2010-06-25 20:21:49 [freenode] Logged in to server calvino.freenode.net with nick foobar1234
+ 2010-06-25 20:21:49 [magnet] Server notice: *** No Ident response
+ 2010-06-25 20:21:49 [magnet] Logged in to server magnet.llarian.net with nick hlagherf32fr
+ 2010-06-25 20:21:51 [freenode] Joined channel #foodsfdsf
+ 2010-06-25 20:21:55 Caught interrupt signal, exiting...
+ 2010-06-25 20:21:55 [freenode] Quit from IRC (Client Quit)
+ 2010-06-25 20:21:55 [freenode] Error from IRC server: Closing Link: 194-144-99-91.du.xdsl.is (Client Quit)
+ 2010-06-25 20:21:55 [freenode] Disconnected from server 213.92.8.4
+ 2010-06-25 20:21:55 [freenode] Shutting down
+ 2010-06-25 20:21:55 [freenode] Deleted plugin DCC3
+ 2010-06-25 20:21:55 [freenode] Deleted plugin AutoJoin2
+ 2010-06-25 20:21:55 [freenode] Deleted plugin CTCP2
+ 2010-06-25 20:21:55 [freenode] Deleted plugin Whois3
+ 2010-06-25 20:21:55 [freenode] Deleted plugin ISupport3
+ 2010-06-25 20:21:55 [magnet] Error from IRC server: Closing Link: 194-144-99-91.du.xdsl.is ()
+ 2010-06-25 20:21:55 [magnet] Disconnected from server 209.221.142.115
+ 2010-06-25 20:21:55 [magnet] Shutting down
+ 2010-06-25 20:21:55 [magnet] Deleted plugin BotTraffic2
+ 2010-06-25 20:21:55 [magnet] Deleted plugin DCC6
+ 2010-06-25 20:21:55 [magnet] Deleted plugin ISupport6
+ 2010-06-25 20:21:55 [magnet] Deleted plugin CTCP2
+ 2010-06-25 20:21:55 [magnet] Deleted plugin Whois6
+
 =head1 TODO
 
 =over 4
